/**
 * 
 */
package controller;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ModelAndView;

import fr.astec.dao.jpa.ErgoDaoJpa;
import fr.astec.entity.ergo.constraint.SingleValueConstraint;
import fr.astec.entity.ergo.expression.PrimitiveNounPhrase;
import fr.astec.entity.ergo.expression.TimePoint;
import fr.astec.entity.ergo.keyword.ExpressionComparator;
import fr.astec.entity.ergo.statement.PhysicalFindingStatement;

/**
 * @author Laurent CHARLOIS
 * @version 1.0
 * 
 */
@Controller
public class TestController {

	@Autowired
	private ErgoDaoJpa	ergoDao;

	/**
	 * @param ergoDao
	 *            the ergoDao to set
	 */
	public void setErgoDao(ErgoDaoJpa ergoDao) {
		this.ergoDao = ergoDao;
	}

	@RequestMapping(value = "/")
	public String get() {
		return "welcome";
	}

	private Long	statementId;
	private Long	comparatorId;

	@RequestMapping(value = "/testCreate")
	public ModelAndView create() {

		ExpressionComparator comparator = new ExpressionComparator();
		comparator.setPreferedName("=");
		ergoDao.saveErgoClass(comparator);
		comparatorId = comparator.getId();

		TimePoint timePoint = new TimePoint();
		timePoint.setLiteral("01-01-2000");
		ergoDao.saveErgoClass(timePoint);

		SingleValueConstraint constraint = new SingleValueConstraint();
		constraint.setComparator(comparator);
		constraint.setValue(timePoint);
		ergoDao.saveErgoClass(constraint);

		PrimitiveNounPhrase nounPhrase = new PrimitiveNounPhrase();
		nounPhrase.setCode("CODE");
		nounPhrase.setCodeSystem("CODE_SYSTEM");
		nounPhrase.setPreferedName("PREFERED_NAME");
		ergoDao.saveErgoClass(nounPhrase);

		PhysicalFindingStatement statement = new PhysicalFindingStatement();
		statement.setType(nounPhrase);
		statement.setDate(constraint);
		ergoDao.saveErgoClass(statement);
		statementId = statement.getId();

		ModelAndView mav = new ModelAndView("welcome");
		mav.addObject("statement", statement);
		return mav;
	}

	@RequestMapping(value = "/testUpdate")
	public ModelAndView update() {
		PhysicalFindingStatement statement = (PhysicalFindingStatement) ergoDao.getErgoClass(statementId);
		ExpressionComparator comparator = (ExpressionComparator) ergoDao.getErgoClass(comparatorId);

		TimePoint timePoint = new TimePoint();
		timePoint.setLiteral("10-10-1900");
		ergoDao.saveErgoClass(timePoint);

		SingleValueConstraint constraint = new SingleValueConstraint();
		constraint.setComparator(comparator);
		constraint.setValue(timePoint);
		ergoDao.saveErgoClass(constraint);

		statement.setValue(constraint);
		ergoDao.updateErgoClass(statement);

		ModelAndView mav = new ModelAndView("welcome");
		mav.addObject("statement", statement);
		return mav;
	}

	@RequestMapping(value = "/refresh")
	public ModelAndView refresh() {
		PhysicalFindingStatement statement = (PhysicalFindingStatement) ergoDao.getErgoClass(statementId);
		ModelAndView mav = new ModelAndView("welcome");
		mav.addObject("statement", statement);
		return mav;
	}

	@RequestMapping(value = "/updateAllInDao")
	public ModelAndView updateAllInDao() {
		ergoDao.specialTest(statementId, comparatorId);
		PhysicalFindingStatement statement = (PhysicalFindingStatement) ergoDao.getErgoClass(statementId);
		ModelAndView mav = new ModelAndView("welcome");
		mav.addObject("statement", statement);
		return mav;
	}

}
