/**
 * 
 */
package fr.astec.dao.jpa;

import java.util.Collection;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.TypedQuery;

import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import fr.astec.entity.ergo.ERGOClass;
import fr.astec.entity.ergo.constraint.SingleValueConstraint;
import fr.astec.entity.ergo.expression.TimePoint;
import fr.astec.entity.ergo.keyword.ExpressionComparator;
import fr.astec.entity.ergo.statement.PhysicalFindingStatement;

/**
 * @author Laurent CHARLOIS
 * @version 1.0
 * 
 */
@Repository
@Transactional
public class ErgoDaoJpa {

	@PersistenceContext
	private EntityManager	entityManager;

	public final void setEntityManager(final EntityManager entityManager) {
		this.entityManager = entityManager;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.dao.IErgoDao#getErgoClass(java.lang.Long)
	 */
	public ERGOClass getErgoClass(Long id) {
		ERGOClass ergoClass = null;
		ergoClass = entityManager.find(ERGOClass.class, id);
		return ergoClass;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.dao.IErgoDao#saveErgoClass(fr.astec.entity.ergo.ERGOClass)
	 */
	public void saveErgoClass(ERGOClass ergoClass) {
		entityManager.persist(ergoClass);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * fr.astec.dao.IErgoDao#updateErgoClass(fr.astec.entity.ergo.ERGOClass)
	 */
	public void updateErgoClass(ERGOClass ergoClass) {
		entityManager.merge(ergoClass);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.dao.IErgoDao#getAllErgoClasses()
	 */
	public Collection<ERGOClass> getAllErgoClasses() {
		TypedQuery<ERGOClass> query;
		query = entityManager.createQuery("SELECT ergoClass FROM ERGOClass ergoClass", ERGOClass.class);
		Collection<ERGOClass> ergoClasses = null;
		ergoClasses = query.getResultList();
		return ergoClasses;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.dao.IErgoDao#getErgoClass(java.lang.Long, java.lang.Class)
	 */
	public <T> T getErgoClass(Long id, Class<T> clazz) {
		T ergoClass;
		ergoClass = entityManager.find(clazz, id);
		return ergoClass;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.dao.IErgoDao#getAllErgoClasses(java.lang.Class)
	 */
	public <T> Collection<T> getAllErgoClasses(Class<T> clazz) {
		TypedQuery<T> query;
		query = entityManager.createQuery("SELECT ergoClass FROM " + clazz.getName() + " ergoClass", clazz);
		Collection<T> ergoClasses = null;
		ergoClasses = query.getResultList();
		return ergoClasses;
	}

	public void specialTest(Long statementId, Long comparatorId) {
		PhysicalFindingStatement statement = entityManager.find(PhysicalFindingStatement.class, statementId);
		ExpressionComparator comparator = entityManager.find(ExpressionComparator.class, comparatorId);

		TimePoint timePoint = new TimePoint();
		timePoint.setLiteral("10-10-1900");
		entityManager.persist(timePoint);

		SingleValueConstraint constraint = new SingleValueConstraint();
		constraint.setComparator(comparator);
		constraint.setValue(timePoint);
		entityManager.persist(constraint);

		statement.setValue(constraint);
		entityManager.merge(statement);

	}
}
