/*
 * 
 */
package fr.astec.entity.ergo.statement;

import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import fr.astec.entity.ergo.ERGOClass;
import fr.astec.entity.ergo.expression.NounPhrase;

// TODO: Auto-generated Javadoc
/**
 * The Class PhysicalFindingStatement.
 * 
 * @author Laurent CHARLOIS
 * @version 1.0
 */
@Entity
@Table(name = "ASTEC_ERGO_PHYSICAL_FINDING_STATEMENT")
@Inheritance(strategy = InheritanceType.TABLE_PER_CLASS)
public class PhysicalFindingStatement extends HealthcareStatement {

	/** The patient position code. */
	@ManyToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "PATIENT_POSITION_CODE", referencedColumnName = "ERGO_CLASS_ID")
	private NounPhrase	patientPositionCode;

	/** The finding location code. */
	@ManyToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "FINDING_LOCATION_CODE", referencedColumnName = "ERGO_CLASS_ID")
	private NounPhrase	findingLocationCode;

	/** The value. Soit une NounPhrase, soit une ValueConstraint. */
	@ManyToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "VALUE", referencedColumnName = "ERGO_CLASS_ID")
	private ERGOClass	value;

	/** The interpretation. */
	@ManyToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "INTERPRETATION", referencedColumnName = "ERGO_CLASS_ID")
	private NounPhrase	interpretation;

	/**
	 * Gets the patient position code.
	 * 
	 * @return the patient position code
	 */
	public NounPhrase getPatientPositionCode() {
		return patientPositionCode;
	}

	/**
	 * Sets the patient position code.
	 * 
	 * @param patientPositionCode
	 *            the new patient position code
	 */
	public void setPatientPositionCode(NounPhrase patientPositionCode) {
		this.patientPositionCode = patientPositionCode;
	}

	/**
	 * Gets the finding location code.
	 * 
	 * @return the finding location code
	 */
	public NounPhrase getFindingLocationCode() {
		return findingLocationCode;
	}

	/**
	 * Sets the finding location code.
	 * 
	 * @param findingLocationCode
	 *            the new finding location code
	 */
	public void setFindingLocationCode(NounPhrase findingLocationCode) {
		this.findingLocationCode = findingLocationCode;
	}

	/**
	 * Gets the value.
	 * 
	 * @return the value
	 */
	public ERGOClass getValue() {
		return value;
	}

	/**
	 * Sets the value.
	 * 
	 * @param value
	 *            the new value
	 */
	public void setValue(ERGOClass value) {
		this.value = value;
	}

	/**
	 * Gets the interpretation.
	 * 
	 * @return the interpretation
	 */
	public NounPhrase getInterpretation() {
		return interpretation;
	}

	/**
	 * Sets the interpretation.
	 * 
	 * @param interpretation
	 *            the new interpretation
	 */
	public void setInterpretation(NounPhrase interpretation) {
		this.interpretation = interpretation;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.ergo.statement.HealthcareStatement#toOWL(java.lang.String)
	 */
	@Override
	public String toOWL(String prefix) {
		StringBuilder sb = new StringBuilder();
		sb.append("<" + prefix + "PhysicalFindingStatement rdf:ID=\"id_" + this.getId() + "\">");
		if (date != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "date>" + date.toOWL(prefix) + "</" + prefix + "date>");
		}
		if (nounPhrase != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "nounPhrase>" + nounPhrase.toOWL(prefix) + "</" + prefix + "nounPhrase>");
		}
		if (type != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "type>" + type.toOWL(prefix) + "</" + prefix + "type>");
		}
		if (value != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "value>" + value.toOWL(prefix) + "</" + prefix + "value>");
		}
		if (interpretation != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "interpretation>" + interpretation.toOWL(prefix) + "</" + prefix + "interpretation>");
		}
		if (findingLocationCode != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "findingLocationCode>" + findingLocationCode.toOWL(prefix) + "</" + prefix + "findingLocationCode>");
		}
		if (patientPositionCode != null) {
			sb.append("\n");
			sb.append("\t");
			sb.append("<" + prefix + "patientPositionCode>" + patientPositionCode.toOWL(prefix) + "</" + prefix + "patientPositionCode>");
		}
		sb.append("\n");
		sb.append("</" + prefix + "PhysicalFindingStatement>");
		sb.append("\n");
		return sb.toString();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see fr.astec.ergo.statement.HealthcareStatement#toString()
	 */
	@Override
	public String toString() {
		return "PhysicalFindingStatement [findingLocationCode=" + findingLocationCode + ", interpretation=" + interpretation + ", patientPositionCode=" + patientPositionCode + ", value=" + value
				+ ", toString()=" + super.toString() + "]";
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * fr.astec.ergo.statement.HealthcareStatement#getConstraintForAttribute
	 * (java.lang.String)
	 */
	@Override
	public ERGOClass getConstraintForAttribute(String attributeName) throws Exception {
		try {
			return super.getConstraintForAttribute(attributeName);
		} catch (Exception e) {
			if (attributeName.equals("value")) {
				return value;
			}
			if (attributeName.equals("patientPosition")) {
				return patientPositionCode;
			}
			if (attributeName.equals("interpretation")) {
				return interpretation;
			}
			if (attributeName.equals("findingLocation")) {
				return findingLocationCode;
			}
			e.getMessage().concat("\nL'attribut \'" + attributeName + "\' n'existe pas dans la classe \'" + this.getClass() + "\'");
			throw e;
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * fr.astec.ergo.statement.HealthcareStatement#setConstraintForAttribute
	 * (java.lang.String, fr.astec.ergo.ERGOClass)
	 */
	@Override
	public void setConstraintForAttribute(String attributeName, ERGOClass constraint) throws Exception {
		try {
			super.setConstraintForAttribute(attributeName, constraint);
		} catch (Exception e) {
			if (attributeName.equals("value")) {
				value = constraint;
				return;
			}
			if (attributeName.equals("patientPosition")) {
				patientPositionCode = (NounPhrase) constraint;
				return;
			}
			if (attributeName.equals("interpretation")) {
				interpretation = (NounPhrase) constraint;
				return;
			}
			if (attributeName.equals("findingLocation")) {
				findingLocationCode = (NounPhrase) constraint;
				return;
			}
			e.getMessage().concat("\nL'attribut \'" + attributeName + "\' n'existe pas dans la classe \'" + this.getClass() + "\'");
			throw e;
		}
	}

}
